@@ -1,4 +1,4 @@
-# $Id: Hooks.pm,v 1.5 2002/05/12 13:35:35 m_ilya Exp $
+# $Id: Hooks.pm,v 1.7 2002/05/17 20:48:57 m_ilya Exp $
 
 package HTTP::WebTest::Plugin::Hooks;
 
@@ -31,10 +31,10 @@ HTTP::WebTest::Plugin::Hooks - Provides callbacks called during test run
 =head1 DESCRIPTION
 
 This plugin module adds test parameters which values are evaluated at
-specific time of L<HTTP::WebTest> test run.  It can be used to do some
-initialization before doing test request, to do some finalization when
-test response is received or to implement user defined tests without
-need to write separate plugin module.
+specific time of L<HTTP::WebTest|HTTP::WebTest> test run.  It can be
+used to do some initialization before doing test request, to do some
+finalization when test response is received or to implement user
+defined tests without need to write separate plugin module.
 
 =cut
 
@@ -45,20 +45,22 @@ use base qw(HTTP::WebTest::Plugin);
 
 =head1 TEST PARAMETERS
 
+=for pod_merge copy opt_params
+
 =head2 on_request
 
 Value of this test parameter is ignored.  However it is evaluted
-before L<HTTP::WebTest> does a request to web page so it is useful to
-do some initalization before the request.
+before test request to web page is done so it is useful to do some
+initalization before the request.
 
 =head2 on_response
 
-This is list parameter which is treated as test result.  It is
-evaluted when L<HTTP::WebTest> gets a response for the test request.
+This is a list parameter which is treated as test result.  It is
+evaluted when response for the test request is received.
 
 It can be useful to define custom tests without writting new plugins
-and/or it can be useful to run some code when L<HTTP::WebTest> got
-some a response for the test request.
+and/or it can be useful to run some code when response for the test
+request is received.
 
 =head3 Allowed values
 
