@@ -1,4 +1,4 @@
-# $Id: ReportPlugin.pm,v 1.2 2002/02/02 04:08:19 m_ilya Exp $
+# $Id: ReportPlugin.pm,v 1.3 2002/05/12 13:35:35 m_ilya Exp $
 
 package HTTP::WebTest::ReportPlugin;
 
@@ -12,11 +12,10 @@ Not applicable.
 
 =head1 DESCRIPTION
 
-This is subclass of
-L<HTTP::WebTest|HTTP::WebTest::Plugin>. L<HTTP::WebTest|HTTP::WebTest>
-report plugin classes can subclass this class. It handles some test
-parameters common to report plugins by providing implementation of
-method C<print>. See below.
+This is subclass of L<HTTP::WebTest|HTTP::WebTest::Plugin>.
+L<HTTP::WebTest|HTTP::WebTest> report plugin classes can subclass this
+class.  It handles some test parameters common to report plugins by
+providing implementation of method C<print>.  See below.
 
 =cut
 
@@ -36,7 +35,7 @@ use base qw(HTTP::WebTest::Plugin);
 
 I<GLOBAL PARAMETER>
 
-A reference on scalar which accumulates text of test report. If this
+A reference on scalar which accumulates text of test report.  If this
 test parameter is specified then value of test parameter C<fh_out> is
 ignore.
 
@@ -48,7 +47,7 @@ as arguments from a calling Perl script.
 I<GLOBAL PARAMETER>
 
 A filehandle (or anything else that supports C<print>) to use for test
-report output. This parameter is ignored if test parameter
+report output.  This parameter is ignored if test parameter
 C<output_ref> is specified also.
 
 This parameter can be used only when passing the test parameters
@@ -169,7 +168,7 @@ sub print {
 =head2 start_tests ()
 
 This method is called by L<HTTP::WebTest|HTTP::WebTest> at the begin
-of test run. Its implementation in this class inits output buffer for
+of test run.  Its implementation in this class inits output buffer for
 test report.
 
 If you redefine this method in subclass be sure to call
@@ -196,7 +195,7 @@ sub start_tests {
 =head2 end_tests ()
 
 This method is called by L<HTTP::WebTest|HTTP::WebTest> at the end of
-test run. Its implementation in this class can email test report
+test run.  Its implementation in this class can email test report
 according test parameters C<mail***>.
 
 If you redefine this method in subclass be sure to call
@@ -272,7 +271,7 @@ sub _smtp_cmd {
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001,2002 Ilya Martynov. All rights reserved.
+Copyright (c) 2001,2002 Ilya Martynov.  All rights reserved.
 
 This module is free software.  It may be used, redistributed and/or
 modified under the terms of the Perl Artistic License.
